slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSNEPGetSamplingSize

Returns the number of sampling columns used in the contour integral method.

### Synopsis

    #include "slepcds.h"
    #include "slepcrg.h"
    PetscErrorCode DSNEPGetSamplingSize(DS ds,PetscInt *p)

Not collective

### Input Parameter

| ds | - the direct solver context

### Output Parameters

| p | - the number of columns for the sampling matrix

### See Also

DSNEPSetSamplingSize()

### Level

advanced

### Location

src/sys/classes/ds/impls/nep/dsnep.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages